==> apache-camel-quarkus-3.30.0-src.zip: camel-quarkus-3.30.0/extensions/netty-http/deployment/src/main/java/org/apache/camel/quarkus/component/netty/http/deployment/NettyHTTPProcessor.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.quarkus.component.netty.http.deployment;

import io.quarkus.deployment.annotations.BuildStep;
import io.quarkus.deployment.builditem.FeatureBuildItem;
import io.quarkus.deployment.builditem.nativeimage.ReflectiveClassBuildItem;

class NettyHTTPProcessor {

    private static final String FEATURE = "camel-netty-http";

    @BuildStep
    FeatureBuildItem feature() {
        return new FeatureBuildItem(FEATURE);
    }

    // Needed when using the default JaasSecurityAuthenticator, otherwise fails with ClassNotFoundException
    @BuildStep
    ReflectiveClassBuildItem registerForReflection() {
        return ReflectiveClassBuildItem
                .builder(
                        "sun.security.provider.ConfigFile",
                        "com.sun.security.auth.module.Krb5LoginModule",
                        "com.sun.security.auth.module.UnixLoginModule",
                        "com.sun.security.auth.module.JndiLoginModule",
                        "com.sun.security.auth.module.KeyStoreLoginModule",
                        "com.sun.security.auth.module.LdapLoginModule",
                        "com.sun.security.auth.module.NTLoginModule",
                        "com.sun.jmx.remote.security.FileLoginModule")
                .build();
    }
}

==> apache-camel-quarkus-3.32.0-src.zip: camel-quarkus-3.32.0/extensions/netty-http/deployment/src/main/java/org/apache/camel/quarkus/component/netty/http/deployment/NettyHTTPProcessor.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.quarkus.component.netty.http.deployment;

import io.quarkus.deployment.annotations.BuildStep;
import io.quarkus.deployment.builditem.FeatureBuildItem;
import io.quarkus.deployment.builditem.nativeimage.NativeImageResourceBundleBuildItem;
import io.quarkus.deployment.builditem.nativeimage.ReflectiveClassBuildItem;

class NettyHTTPProcessor {

    private static final String FEATURE = "camel-netty-http";

    @BuildStep
    FeatureBuildItem feature() {
        return new FeatureBuildItem(FEATURE);
    }

    // Needed when using the default JaasSecurityAuthenticator, otherwise fails with ClassNotFoundException
    @BuildStep
    ReflectiveClassBuildItem registerForReflection() {
        return ReflectiveClassBuildItem
                .builder(
                        "sun.security.provider.ConfigFile",
                        "com.sun.security.auth.module.Krb5LoginModule",
                        "com.sun.security.auth.module.UnixLoginModule",
                        "com.sun.security.auth.module.JndiLoginModule",
                        "com.sun.security.auth.module.KeyStoreLoginModule",
                        "com.sun.security.auth.module.LdapLoginModule",
                        "com.sun.security.auth.module.NTLoginModule",
                        "com.sun.jmx.remote.security.FileLoginModule")
                .build();
    }

    @BuildStep
    NativeImageResourceBundleBuildItem nativeImageResoourceResourceBundles() {
        return new NativeImageResourceBundleBuildItem("sun.security.util.resources.security");
    }
}
